/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWSERVICES_OP_NAMESPACE_HPP__
#define __FWSERVICES_OP_NAMESPACE_HPP__

namespace fwServices
{
/**
 * @brief       The namespace fwServices::op contains several methods for managing services to object
 * @namespace   fwServices::op
 *
 * @date        2009-2010.
 *
 */
namespace op
{

}
}
#endif /* __FWSERVICES_OP_NAMESPACE_HPP__ */
